<?php
$GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] ?: array()) + array("_db6f0ba0791e9a635" . "407659a9fe04e40" => base64_decode("aXNfb2JqZ" . "WN0"));
use Claromentis\Core\Http\gpc as gpcNew;






class gpc
{
    protected static $request_instance = 1;
    
    
    
    
    
    
    public static function GetHttpRequestInstance()
    {
        if (!$GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_db6f0ba0791e" . "9a635407659a9" . "fe04e40"](self::$request_instance)) {
            self::$request_instance = new HttpBaseRequest();
        }
        return self::$request_instance;
    }
    
    
    
    
    
    
    
    
    
    
    public static function GetInt($name, $error_message = 'Wrong integer: "%s"', $type = InputFilter::INT_NOT_NULL)
    {
        if ($type == InputFilter::INT_OR_NULL) {
            return self::GetIntOrNull($name, $error_message);
        }
        $_c96f552040dea8086bf8bdd70059542f = self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, InputFilter::INT_NOT_NULL);
        return $_c96f552040dea8086bf8bdd70059542f;
    }
    
    
    
    
    
    
    
    
    public static function GetIntOrNull($name, $error_message = 'Wrong integer: "%s"')
    {
        $_c96f552040dea8086bf8bdd70059542f = self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, InputFilter::INT_OR_NULL);
        if (InputFilter::IsEmptyString($_c96f552040dea8086bf8bdd70059542f)) {
            $_c96f552040dea8086bf8bdd70059542f = null;
        }
        return $_c96f552040dea8086bf8bdd70059542f;
    }
    
    
    
    
    
    
    
    
    public static function GetFloat($name, $error_message = 'Wrong float: "%s"')
    {
        $_c96f552040dea8086bf8bdd70059542f = self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, InputFilter::FLOAT_NOT_NULL);
        return $_c96f552040dea8086bf8bdd70059542f;
    }
    
    
    
    
    
    
    
    
    public static function GetFloatOrNull($name, $error_message = 'Wrong float: "%s"')
    {
        $_c96f552040dea8086bf8bdd70059542f = self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, InputFilter::FLOAT_OR_NULL);
        if (InputFilter::IsEmptyString($_c96f552040dea8086bf8bdd70059542f)) {
            $_c96f552040dea8086bf8bdd70059542f = null;
        }
        return $_c96f552040dea8086bf8bdd70059542f;
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function GetString($name, $error_message = 'Wrong string: "%s"', $type = InputFilter::STRING_NOT_EMPTY)
    {
        return self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, $type);
    }
    
    
    
    
    
    
    
    
    
    
    public static function GetStringOrNull($name, $error_message = 'Wrong string: "%s"')
    {
        return self::GetString($name, $error_message, InputFilter::STRING_OR_EMPTY);
    }
    
    
    
    
    
    
    
    
    
    public static function GetArray($name, $error_message = 'Wrong array: "%s"', $type = InputFilter::ARRAY_NOT_NULL)
    {
        return self::GetHttpRequestInstance()->GetValidatedVariable($name, $error_message, $type);
    }
    
    
    
    
    
    
    
    
    public static function GetArrayOrNull($name, $error_message = 'Wrong array: "%s"')
    {
        return self::GetArray($name, $error_message, InputFilter::ARRAY_OR_NULL);
    }
    public static function IsError()
    {
        return self::GetHttpRequestInstance()->IsError();
    }
    public static function GetErrMsg()
    {
        return self::GetHttpRequestInstance()->GetErrMsg();
    }
    public static function ResetError()
    {
        self::GetHttpRequestInstance()->ResetError();
    }
    
    
    
    
    
    
    
    
    
    
    
    public static function IsSubmit($_fd9abf76fd2d2f2325b7cdba6082e462 = false, $_174e48cbcec1c1408123865df95cf127 = true)
    {
        global $g_request;
        return gpcNew::IsSubmit($g_request, $_fd9abf76fd2d2f2325b7cdba6082e462, $_174e48cbcec1c1408123865df95cf127);
    }
    
    
    
    
    
    
    
    
    public static function CheckToken()
    {
        global $g_request;
        gpcNew::CheckToken($g_request);
        return true;
    }
}