<?php
namespace Claromentis\Blog\Controller;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"] ?: array()) + array("_e1f397b7c2d69b7a7831fae03f3f" . "5e94" => base64_decode("YmxvZy5jaGFubmVsX2VkaXQuY3" . "JlYXRlZA=="), "_0ae3807d8d61bb64354b" . "1bd7c3a20b57" => base64_decode("YmxvZy9jaGFubmVsX2" . "VkaXQuaHRtbA=="), "_07ccde2e1abe46a6e" . "90b9fa1767bb33a" => base64_decode("ZGV" . "sZX" . "Rl"), "ar" . "gs" => base64_decode("YXJnc" . "w=="), "_d5e3acfe4" . "93fa2111d2" . "2dfb93da33" . "d87" => base64_decode("X18" . "="), "_169371a8b8b80416e0109e2" . "17a6255b0" => base64_decode("YmxvZy5jaGFubmVsX2Vka" . "XQuZGVsZXRlZA=="), "_8df4fa2d5c8d8c2e6de4577a36506" . "bb1" => base64_decode("aXNfZXJyb3JfbWVzc2" . "FnZQ=="), "_8c090977da" . "1a3dd4e737f" . "40bd6ee29e3" => base64_decode("bW92" . "ZV90" . "bw=="), "_e05e0022a2e5ad344b9c4a" . "0d3f64e1a5" => base64_decode("bWVzc2F" . "nZQ=="), "_ba9b6c9" . "7c9c752d" . "4b80eab7" . "9577a436" . "1" => base64_decode("YmxvZy9jaGFubmVsX2Rl" . "bGV0ZS5odG1s"), "_678d94525" . "8a520c3df1" . "c42fe4b558" . "f34" => base64_decode("cGFnZV" . "90aXRs" . "ZQ=="), "tem" . "pla" . "te" => base64_decode("dGV" . "tcG" . "xhd" . "GU="), "_aa010f01c5fa75b081f8a35ef259" . "d278" => base64_decode("YmxvZy5jaGFu" . "bmVsX2VkaXQu" . "bm9fcmlnaHRz"), "_0c38283cc2" . "a07ab442bd1" . "6754415a84f" => base64_decode("ZGVsZXRlX" . "29wdGlvbg" . "=="), "_87d793fb0c87299bd43f41" . "8405815498" => base64_decode("YmxvZy5jaGFubmVsX2V" . "kaXQudXBkYXRlZA=="), "_21085f50c670b0762b9848ca" . "2d377a12" => base64_decode("L2RlbGV0" . "ZQ=="), "_106fdbc94b" . "b1ea87caca3" . "0b55467bf26" => base64_decode("Tm8gcmlnaHRzIH" . "RvIG1vdmUgdG8g" . "dGhpcyBibG9nIG" . "NoYW5uZWw="), "_0c5123aa7" . "44f69bbc0e" . "8b3ea2f6e8" . "47d" => base64_decode("bG1z" . "Zw=="), "_87daa84e346f6420a3f3426e" . "05d16a7b" => base64_decode("L" . "w" . "=" . "="), "_ae4a14ab8049cb004f15102f46849" . "e09" => base64_decode("L2NoYW5" . "uZWxzLw" . "=="), "_5b507e9f50e79fb69e3fc508" . "d625da72" => base64_decode("YmxvZy5jaGFu" . "bmVscy5ub19j" . "cmVhdGVfcGVy" . "bWlzc2lvbg=="));
use BlogChannel;
use AuthUser;
use Claromentis\Blog\BlogApplication;
use Claromentis\Blog\Exception\ControllerException;
use Claromentis\Core\Application;
use Claromentis\Core\Http\gpc;
use Claromentis\Core\Http\RedirectResponse;
use Claromentis\Core\Http\TemplaterCallResponse;
use Claromentis\Core\Security\SecurityContext;
use Permissions;
use Psr\Http\Message\ServerRequestInterface;






class UserChannelsEditController extends AbstractChannelsEditController
{
    public function OnShowList(SecurityContext $context) : TemplaterCallResponse
    {
        $_1f24efd4735b7a11b391147435e7d35d = $this->ShowChannelsList(BlogChannel::GetEditable($context), $context);
        return new TemplaterCallResponse($_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["tem" . "pla" . "te"]], $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["arg" . "s"]], $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653e8a0ab7" . "848e536215"]["_678d945258a" . "520c3df1c42f" . "e4b558f34"]]);
    }
    public function OnPreDelete(Application $app, $channel)
    {
        $_1f24efd4735b7a11b391147435e7d35d = $this->ShowPreDeleteform($app, $channel);
        $template = $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_ba9b6c9" . "7c9c752d" . "4b80eab7" . "9577a436" . "1"];
        return new TemplaterCallResponse($template, $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["arg" . "s"]], $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_678d945258a520c3df1c42fe4b558f" . "34"]]);
    }
    public function OnConfirmDelete(Application $app, ServerRequestInterface $request, $channel)
    {
        $_8c090977da1a3dd4e737f40bd6ee29e3 = gpc::get($request, $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_0c38283cc2" . "a07ab442bd1" . "6754415a84f"]) === $GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_07ccde2e1abe46a6e90b9fa1767bb3" . "3a"] ? 0 : gpc::get($request, $GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_8c090977d" . "a1a3dd4e73" . "7f40bd6ee2" . "9e3"]);
        if ($_8c090977da1a3dd4e737f40bd6ee29e3 && !Permissions::HasPermissions(PERM_EDIT_APPROVE, PERM_CLASS_BLOG_CHANNEL, $_8c090977da1a3dd4e737f40bd6ee29e3)) {
            return RedirectResponse::httpRedirect(BlogApplication::BASE_URL . $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_ae4a14ab8049cb004f15102f46849e" . "09"], $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_d5e3acfe493fa" . "2111d22dfb93da" . "33d87"]($GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_106fdbc" . "94bb1ea8" . "7caca30b" . "55467bf2" . "6"]), 1);
        }
        $blog_channel = $this->GetBlogChannel($channel);
        $_8c090977da1a3dd4e737f40bd6ee29e3 = gpc::get($request, $GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["_0c38283cc2a07ab442bd1675441" . "5a84f"]) === $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_07ccde2e1abe46a6e90b" . "9fa1767bb33a"] ? 0 : gpc::get($request, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"]["_8c090977da1a3" . "dd4e737f40bd6e" . "e29e3"]);
        try {
            gpc::CheckToken($request);
        } catch (\TokenException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            return RedirectResponse::httpRedirect(BlogApplication::BASE_URL . $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_87daa84e346f6420a3f3426e" . "05d16a7b"] . $channel . $GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_21085f50c670b" . "0762b9848ca2d3" . "77a12"], $_fe441aa3ef350bfb1a1a1ad8520dd530->getMessage(), true);
        }
        $blog_channel->Delete($_8c090977da1a3dd4e737f40bd6ee29e3);
        return RedirectResponse::httpRedirect(BlogApplication::BASE_URL . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_ae4a14ab8049cb004f15102f46849e" . "09"], $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_0c5123aa744f69bbc0e8b3ea2f6e8" . "47d"]($GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"]["_169371a8b8b80416e0" . "109e217a6255b0"]));
    }
    public function OnShowChannelEdit(Application $app, ServerRequestInterface $request, $channel = null)
    {
        $blog_channel = $this->GetBlogChannel($channel);
        if (!$blog_channel->id && !$blog_channel->UserCanCreateChannel($app->security)) {
            return RedirectResponse::httpRedirect(BlogApplication::BASE_URL . $GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"]["_ae4a14ab" . "8049cb004" . "f15102f46" . "849e09"], $GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_0c5123aa744f69b" . "bc0e8b3ea2f6e847" . "d"]($GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"]["_5b507e9f50e79fb69e3fc508d6" . "25da72"]), true);
        }
        $_1f24efd4735b7a11b391147435e7d35d = $this->ShowEditChannelForm($blog_channel);
        $template = $GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_0ae3807d8d61bb64354b1b" . "d7c3a20b57"];
        $_fd5a3a643834299cbdadfc3540ba0bcb = new TemplaterCallResponse($template, $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"]["a" . "r" . "g" . "s"]], $_1f24efd4735b7a11b391147435e7d35d[$GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_678d945258a520c3df1" . "c42fe4b558f34"]]);
        $_e05e0022a2e5ad344b9c4a0d3f64e1a5 = gpc::GetStringOrNull($request, $GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_e05e0022a2e5ad" . "344b9c4a0d3f64e" . "1a5"]);
        if ($_e05e0022a2e5ad344b9c4a0d3f64e1a5 !== null) {
            $_fd5a3a643834299cbdadfc3540ba0bcb->message = $_e05e0022a2e5ad344b9c4a0d3f64e1a5;
            $_fd5a3a643834299cbdadfc3540ba0bcb->is_error_message = gpc::GetInt($request, $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_8df4fa2d5c8d8c2e6de4577a36506" . "bb1"]);
        }
        return $_fd5a3a643834299cbdadfc3540ba0bcb;
    }
    public function OnSaveChannel(Application $app, SecurityContext $context, ServerRequestInterface $request, $channel = null)
    {
        try {
            $blog_channel = $this->GetBlogChannel($channel);
            $_2bd573592d12126d3aa08c722788c86a = $blog_channel->id > 0;
            if (!$blog_channel->UserCanCreateChannel($context) && !$_2bd573592d12126d3aa08c722788c86a) {
                throw new ControllerException($blog_channel->GetErrMsg());
            }
            $this->ReadChannelFormData($request, $blog_channel);
            if (!$blog_channel->Save()) {
                throw new ControllerException($blog_channel->GetErrMsg());
            }
            $_a18f3f2e515f9b634cee4e5fbdcdb572 = $blog_channel->GetPermissions();
            if (!$_a18f3f2e515f9b634cee4e5fbdcdb572->Save()) {
                throw new ControllerException($_a18f3f2e515f9b634cee4e5fbdcdb572->GetErrMsg());
            }
            $_e05e0022a2e5ad344b9c4a0d3f64e1a5 = $_2bd573592d12126d3aa08c722788c86a ? $GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_0c5123aa744f69bbc0e8b3ea2f" . "6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848" . "e536215"]["_87d793fb0c8729" . "9bd43f418405815" . "498"]) : $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_0c5123aa" . "744f69bbc" . "0e8b3ea2f" . "6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"]["_e1f397b7c2d69b7a7831fa" . "e03f3f5e94"]);
            return RedirectResponse::httpRedirect(BlogApplication::BASE_URL . $GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_ae4a14a" . "b8049cb0" . "04f15102" . "f46849e0" . "9"], $_e05e0022a2e5ad344b9c4a0d3f64e1a5);
        } catch (ControllerException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            $_e05e0022a2e5ad344b9c4a0d3f64e1a5 = $_fe441aa3ef350bfb1a1a1ad8520dd530->getMessage();
            $request = $request->withQueryParams([$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"]["_e05e0022a2e5ad344b9c" . "4a0d3f64e1a5"] => $_e05e0022a2e5ad344b9c4a0d3f64e1a5, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_8df4fa2d5c8d8c2e" . "6de4577a36506bb1"] => 1] + $request->getQueryParams());
            return $this->OnShowChannelEdit($app, $request, $channel);
        } catch (\TokenException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            $_e05e0022a2e5ad344b9c4a0d3f64e1a5 = $_fe441aa3ef350bfb1a1a1ad8520dd530->getMessage();
            $request = $request->withQueryParams([$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_e05e0022a2e5a" . "d344b9c4a0d3f6" . "4e1a5"] => $_e05e0022a2e5ad344b9c4a0d3f64e1a5, $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_8df4fa2d5c8d8" . "c2e6de4577a365" . "06bb1"] => 1] + $request->getQueryParams());
            return $this->OnShowChannelEdit($app, $request, $channel);
        }
    }
    protected function GetBlogChannel($channel_id)
    {
        if (!$this->blog_channel) {
            $blog_channel = parent::GetBlogChannel($channel_id);
            if (!$blog_channel->id) {
                $blog_channel->owner_id = AuthUser::I()->GetId();
            }
            if ($blog_channel->owner_id != AuthUser::I()->GetId() && !$blog_channel->UserHasPermission(PERM_EDIT_PERMS)) {
                throw new ControllerException($GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"]["_0c5123aa744f69bbc0e8b" . "3ea2f6e847d"]($GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"]["_aa010f01c5fa75b" . "081f8a35ef259d27" . "8"]));
            }
            $this->blog_channel = $blog_channel;
        }
        return $this->blog_channel;
    }
    
    
    
    
    
    protected function ReadChannelFormData(ServerRequestInterface $request, BlogChannel $blog_channel)
    {
        try {
            gpc::CheckToken($request);
        } catch (\TokenException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            throw $_fe441aa3ef350bfb1a1a1ad8520dd530;
        }
        if (!$blog_channel->owner_id) {
            $blog_channel->owner_id = AuthUser::I()->GetId();
        }
        parent::ReadChannelFormData($request, $blog_channel);
        $_a18f3f2e515f9b634cee4e5fbdcdb572 = $blog_channel->GetPermissions();
        if (!$_a18f3f2e515f9b634cee4e5fbdcdb572->UserHasPermission(PERM_EDIT_PERMS)) {
            $_a18f3f2e515f9b634cee4e5fbdcdb572->Add(PERM_EDIT_PERMS, PERM_OCLASS_INDIVIDUAL, AuthUser::I()->GetId());
        }
    }
}